import logging
from importlib.metadata import entry_points

from hatchet_sdk.runnables.workflow import Workflow

from knoc.models import WorkflowPlugin

logger = logging.getLogger("knoc.workflows")

workflows: dict[str, WorkflowPlugin] = {}


def get_plugins():
    for entry_point in entry_points().select(group="knoc.workflow"):
        try:
            wf = entry_point.load()
        except Exception as err:
            logger.warning(f"Cannot load CLI module {entry_point.name} - see below")
            logger.exception(err)
            continue
        if not isinstance(wf, Workflow):
            logger.warning(f"CLI module {entry_point.name} is not a Typer")
            continue
        workflows[entry_point.value] = WorkflowPlugin(
            id=entry_point.name,
            module=entry_point.module,
            description=wf.config.description or wf.name.capitalize().replace("-", " "),
            wf=wf,
        )


get_plugins()
